#
# spec file for package switchboard-plug-keyboard
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.settings.keyboard
Name:           switchboard-plug-keyboard
Version:        8.0.1
Release:        1.3
Summary:        Switchboard Keyboard Plug
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/switchboard-plug-keyboard
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(granite-7)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libgnomekbd)
BuildRequires:  pkgconfig(libgnomekbdui)
BuildRequires:  pkgconfig(libxklavier)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(switchboard-3)
Requires:       switchboard

%description
Adjust keyboard settings from Switchboard. This plug can be used to change
several keyboard settings, for example the delay and speed of the key
repetition, or the cursor blinking speed. You can change your keyboard
layout, and use multiple layouts at the same time. Keyboard shortcuts are
also part of this plug.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc README.md
%dir %{_libdir}/{switchboard-3,switchboard-3/hardware}
%{_libdir}/switchboard-3/hardware/libkeyboard.so
%{_datadir}/metainfo/%{appid}.metainfo.xml
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml

%files lang -f %{appid}.lang

%changelog
* Tue Nov 12 2024 Richard Rahl <rrahl0@opensuse.org>
- Require switchboard at runtime
* Fri Aug 23 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.1:
  * Use new keybindings schema
  * Use new behavior schema
  * Updated translations
* Fri Aug  9 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Updated shortcut category icons
  * Improved screen reader accessibility
  * New shortcut settings for launching dock items
  * Clearer actions for managing keyboard layouts
  * Updated translations
- update to 3.2.1:
  * Layout: remove panel indicator settings
  * Behavior: move onboard to the behavior
  * Shortcuts: Allow assigning PrintScreen key
  * InputMethod: Fix ProgressDialog is not used
  * InstallEngineDialog: Replace stack with Deck
  * Check if Granite.accel_to_string returns null
  * Layout: remove leftovers from onscreen keyboard
  * Add .editorconfig
  * Drop Pantheon namespace
  * Add switch-group shortcut
  * Work around bug with duplicating input methods
- update to 3.2.0:
  * Add link to custom shortcuts
  * Behavior: Remove trailing space in string
  * Behavior: Remove spinbuttons
  * Metainfo Improvements
- update to 3.1.1:
  * Gresource windows category icon
  * ShortcutListBox: only add ShortcutRow when schema key is valid
- update to 3.1.0:
  * Revert shortcuts to default
  * Easily disable a shortcut
  * Support Rime input method for Chinese
  * Remove custom shortcuts from their menu
  * Updated translations
- update to 3.0.0:
  * Updated translations
- update to 2.7.0:
  * Open Multitasking View with Super
  * Updated translations
- update to 2.6.0:
  * Redesigned custom shortcuts view
  * On-screen keyboard switch in Layouts tab
  * Updated translations
- update to 2.5.1:
  * Ensure IBus automatically starts on login when needed
  * Updated translations
- update to 2.5.0:
  * Add Layout popover is now a dialog
  * Guarantee we always have at least one layout
  * Improvements to ibus and xkb layouts
  * Updated translations
- update to 2.4.1:
  * Shortcut description for "Play" is now "Play/Pause"
  * Fix an issue where some shortcuts would incorrectly show as disabled
  * Updated translations
- update to 2.4.0:
  * Add a view to configure input methods
  * Updated translations
- update to 2.3.6:
  * New "Workspaces" icon
  * Exclude Space from single-key shortcuts
  * Updated translations
- switch url to github, as we don't want to link to a different OS
* Tue Mar 12 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.3.5:
  * New upstream release.
* Thu Nov  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Add regex for filtering provided libraries
* Wed Oct 17 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.3.4:
  * New upstream release.
* Mon Jun 11 2018 avvissu@yandex.by
- Update to 0.3.3:
  * New upstream release.
* Sat Jun  9 2018 avvissu@yandex.by
- Switch to github
- Switch to meson
- Drop switchboard-plug-keyboard-0.3.2-vala-0.36.patch
- Add COPYING and README files
- Spec file cleanup
* Mon Jun  5 2017 avvissu@yandex.by
- Build with vala >= 0.36:
  * add switchboard-plug-keyboard-0.3.2-vala-0.36.patch
* Tue Feb  7 2017 avvissu@yandex.by
- Update to 0.3.2:
  * Launchpad automatic translations update.
  * Allow Printscreen key as a shortcut
  * Implement the new URL scheme specification
- Spec file cleanup
* Fri Dec  9 2016 avvissu@yandex.by
- Update to 0.3.1
* Sun Sep 18 2016 avvissu@yandex.by
- Update to 0.3
- Spec file cleanup
* Wed Sep 16 2015 and.november@opensuse.org
- initial package (version 0.2.1) for build.opensuse.org
